from setuptools import setup, find_packages
from setuptools.command.install import install

def post_install():
    print('¡Bienvenido a miPaquete!')

class CustomInstallCommand(install):
    def run(self):
        install.run(self)
        post_install()


setup(
    name='miPaqueteSuperRandom',
    version='0.7',
    packages=find_packages(),
    install_requires=[
        'requests'
    ],
    author='Random guy',
    author_email='random@email.com',
    description='Random description',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    license='MIT',
    keywords='paquete ejemplo',
    cmdclass={
        'install': CustomInstallCommand,
    }
)